@@ -4,14 +4,7 @@
 #include <string>
 #include <iostream>
 
-
-// C++14 implements the ""s literal -> std::string but there are so many issues with it (namespace, gcc warnings)
-// just stick with the home-made version
-
-inline std::string operator "" _s(const char* p, size_t s)
-{
-  return std::string(p, p + s);
-}
+using namespace std::string_literals;
 
 template<typename T>
 std::string to_string_impl(T v)
