@@ -1,4 +1,5 @@
 #include "Sobol.h"
+#include "Log.h"
 
 #include <limits>
 #include <stdexcept>
@@ -7,6 +8,11 @@
 
 Sobol::Sobol(size_t dim, uint32_t nSkip) : m_dim(dim), m_buf(dim), m_pos(dim) // ensures m_buf gets populated on 1st access
 {
+  if (dim < 1 || dim > 1111)
+  {
+    throw std::range_error("Dim %% is not in valid range [1,1111]"s % dim);
+  }
+
   m_s = nlopt_sobol_create(dim);
   if (nSkip > 0)
     skip(nSkip);
@@ -21,7 +27,7 @@ const std::vector<uint32_t>& Sobol::buf()
 {
   // TODO assert m_pos != m_dim|0 ? (i.e some of seq already used)
   if (!nlopt_sobol_next(m_s, &m_buf[0]))
-    throw std::runtime_error("Exceeded generation limit (2^32-1)");
+    throw std::out_of_range("Exceeded generation limit (2^32-1)");
   return m_buf;
 }
 
@@ -29,8 +35,7 @@ uint32_t Sobol::operator()()
 {
   if (m_pos == m_dim)
   {
-    if (!nlopt_sobol_next(m_s, &m_buf[0]))
-      throw std::runtime_error("Exceeded generation limit (2^32-1)");
+    buf();
     m_pos = 0;
   }
   return m_buf[m_pos++];
@@ -39,18 +44,7 @@ uint32_t Sobol::operator()()
 // Skip largest 2^k-1 < n
 void Sobol::skip(uint32_t n)
 {
-  uint32_t b = 0;
-  while (n > 1)
-  {
-    ++b;
-    n >>= 1;
-  }
-
-  uint32_t k = 1 << b;
-  while (k--)
-  {
-    buf();
-  }
+  nlopt_sobol_skip(m_s, n, m_buf.data());
 }
 
 
